@@ -6,7 +6,8 @@
 int
 __open(const char * filename, int flag, ...)
 {
-	register int res asm ("%d0") = SYS_open;
+	int res;
+	register int d0 asm ("%d0");
 	va_list arg;
 
 	va_start(arg,flag);
@@ -14,10 +15,11 @@ __open(const char * filename, int flag, ...)
                 "movel %3,%/d2\n\t"
                 "movel %4,%/d3\n\t"
                 "trap #0\n\t"
-		:"=g" (res)
+		:"=g" (d0)
 		:"0" (SYS_open),"g" (filename),"g" (flag),
-                 "d" (va_arg(arg,int))
+                 "g" (va_arg(arg,int))
                 : "%d0", "%d1", "%d2", "%d3");
+	res = d0;
 	if (res>=0)
 		return res;
 	errno = -res;
